OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mas, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true nele. ",
    "See %s" : "Ver %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplicação %1$s não está presente ou possui uma versão não compatível com este servidor. Verifique o diretório de aplicativos.",
    "Sample configuration detected" : "Configuração de exemplo detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
    "%s email verification" : "%s e-mail de verificação",
    "Email verification" : "E-mail de verificação",
    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu e-mail.",
    "Click the following link to confirm your email." : "Clique no link a seguir para confirmar seu e-mail.",
    "Confirm your email" : "Confirme seu e-mail",
    "Other activities" : "Outras atividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education bundle" : "Pacote educacional",
    "Enterprise bundle" : "Pacote Enterprise",
    "Groupware bundle" : "Pacote Groupware",
    "Hub bundle" : "Pacote de hub",
    "Public sector bundle" : "Pacote do setor público",
    "Social sharing bundle" : "Pacote de compartilhamento social",
    "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
    "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
    "%sbit or higher PHP required." : "%sbit ou PHP maior é requerido.",
    "The following architectures are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "The following databases are supported: %s" : "Os seguintes bancos de dados são suportados: %s",
    "The command line tool %s could not be found" : "A ferramenta de linha de comando %s não pôde ser encontrada",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão maior que %2$s é requerida - versão disponível %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão abaixo de%2$s é requerida - versão disponível %3$s.",
    "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
    "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta conectada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
    "Your current IP address doesn’t allow you to perform admin actions" : "Seu endereço IP atual não permite que você execute ações administrativas",
    "Logged in account must be an admin or sub admin" : "A conta conectada deve ser de um administrador ou subadministrador",
    "Logged in account must be an admin" : "A conta logada deve ser de um administrador",
    "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
    "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
    "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicativo »%s« iniciou o processo de limpeza remota. Você receberá outro e-mail assim que terminar",
    "Wiping of device %s has finished" : "Limpeza do dispositivo %s terminou",
    "Wiping of device »%s« has finished" : "Limpeza do dispositivo »%s« terminou",
    "»%s« finished remote wipe" : "»%s« terminou a limpeza remota",
    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicativo »%s« terminou o processo de limpeza remota.",
    "Remote wipe started" : "Limpeza remota iniciada",
    "A remote wipe was started on device %s" : "Uma limpeza remota iniciou no dispositivo %s",
    "Remote wipe finished" : "Limpeza remota terminada",
    "The remote wipe on %s has finished" : "A limpeza remota em %s terminou",
    "Authentication" : "Autenticação",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada",
    "Files" : "Arquivos",
    "View profile" : "Visualizar perfil",
    "Local time: %s" : "Hora local: %s",
    "today" : "hoje",
    "tomorrow" : "amanhã",
    "yesterday" : "ontem",
    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias","em %n dias"],
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
    "next month" : "Mês que vem",
    "last month" : "último mês",
    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses","há %n meses"],
    "next year" : "ano que vem",
    "last year" : "último ano",
    "_in %n year_::_in %n years_" : ["em %n ano","em %n anos","em %n anos"],
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
    "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas","em %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas","há %n horas"],
    "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos","em %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos","há %n minutos"],
    "in a few seconds" : "Em alguns segundos",
    "seconds ago" : "segundos atrás",
    "Empty file" : "Arquivo vazio",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
    "Dot files are not allowed" : "Arquivos Dot não são permitidos",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" é um nome de arquivo ou pasta proibido.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" é um prefixo proibido para nomes de arquivos ou pastas.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" não é permitido dentro de um nome de arquivo ou pasta.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" é um tipo de arquivo proibido.",
    "Filenames must not end with \"%1$s\"." : "Os nomes dos arquivos não devem terminar com \"%1$s\".",
    "Invalid parent path" : "Caminho mãe inválido",
    "File already exists" : "O arquivo já existe",
    "Invalid path" : "Diretório inválido",
    "Failed to create file from template" : "Falha ao criar arquivo do modelo ",
    "Templates" : "Modelos ",
    "Path contains invalid segments" : "O caminho contém segmentos inválidos",
    "Filename is a reserved word" : "Nome do arquivo é uma palavra reservada",
    "Filename contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido  ",
    "Filename is too long" : "O nome do arquivo é muito longo",
    "Empty filename is not allowed" : "Nome vazio para arquivo não é permitido.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "O aplicativo \"%s\" não pode ser instalado pois o arquivo appinfo não pôde ser lido.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "O aplicativo \"%s\" não pode ser instalado pois não é compatível com a versão do servidor.",
    "__language_name__" : "Português Brasileiro",
    "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
    "Help & privacy" : "Ajuda & privacidade",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "Apps" : "Aplicativos",
    "Personal settings" : "Configurações pessoais",
    "Administration settings" : "Configurações de administração",
    "Settings" : "Configurações",
    "Log out" : "Sair",
    "Accounts" : "Contas",
    "Email" : "E-mail",
    "Mail %s" : "E-Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Ver %s no fediverse",
    "Phone" : "Fone",
    "Call %s" : "Chamar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Visualizar %s no Twitter",
    "Website" : "Website",
    "Visit %s" : "Visitar %s",
    "Address" : "Endereço",
    "Profile picture" : "Foto do perfil",
    "About" : "Sobre",
    "Display name" : "Nome de exibição",
    "Headline" : "Título ",
    "Organisation" : "Organização",
    "Role" : "Função",
    "Unknown account" : "Conta desconhecida",
    "Additional settings" : "Configurações adicionais",
    "Enter the database Login and name for %s" : "Insira o login e o nome do banco de dados para %s",
    "Enter the database Login for %s" : "Insira o login do banco de dados para %s",
    "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
    "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
    "MySQL Login and/or password not valid" : "Login e/ou senha do MySQL inválidos",
    "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
    "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
    "Oracle Login and/or password not valid" : "Login e/ou senha Oracle inválidos",
    "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
    "Set an admin Login." : "Defina um login de administrador.",
    "Set an admin password." : "Defina uma senha para o administrador.",
    "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A plataforma de compartilhamento %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Plataforma de serviço de compartilhamento %s não encontrada",
    "Sharing backend for %s not found" : "Plataforma  de compartilhamento para %s não foi encontrada",
    "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
    "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartilhou »%2$s« com você e quer adicionar:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartilhou »%2$s« com você e quer adicionar",
    "»%s« added a note to a file shared with you" : "»%s« adicionou uma anotação num arquivo compartilhado com você",
    "Unknown share type" : "Tipo de compartilhamento desconhecido",
    "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
    "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
    "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
    "Files cannot be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
    "Expiration date is in the past" : "Data de expiração está no passado",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
    "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
    "Sharing %s failed, because this item is already shared with the account %s" : "Falha no compartilhamento %s porque este item já está compartilhado com a conta %s",
    "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
    "The requested share comes from a disabled user" : "O compartilhamento solicitado vem de um usuário desabilitado",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
    "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
    "Input text" : "Entrada de texto",
    "The input text" : "O texto de entrada",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sab.",
    "Su" : "Su",
    "Mo" : "Se",
    "Tu" : "Te",
    "We" : "Qu",
    "Th" : "Qu",
    "Fr" : "Se",
    "Sa" : "Sa",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "A valid password must be provided" : "Uma senha válida deve ser fornecida",
    "The Login is already being used" : "O Login já está sendo usado",
    "Could not create account" : "Não foi possível criar a conta",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um Login: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
    "A valid Login must be provided" : "Um login válido deve ser fornecido",
    "Login contains whitespace at the beginning or at the end" : "O login contém espaços em branco no início ou no final",
    "Login must not consist of dots only" : "O login não deve consistir apenas em pontos",
    "Login is invalid because files already exist for this user" : "O login é inválido porque já existem arquivos para este usuário",
    "Account disabled" : "Conta desativada",
    "Login canceled by app" : "Login cancelado pelo aplicativo",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
    "a safe home for all your data" : "Um lar seguro para todos os seus dados",
    "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
    "Cannot download file" : "Não é possível baixar o arquivo",
    "Application is not enabled" : "O aplicativo não está habilitado",
    "Authentication error" : "Erro de autenticação",
    "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql ou postgresql) instalado.",
    "Cannot write into \"config\" directory." : "Não é possível gravar no diretório \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Ver %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
    "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a App Store no arquivo de configuração.",
    "Cannot create \"data\" directory." : "Não é possível criar o diretório \"dados\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Ver %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "As permissões geralmente podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Ver %s.",
    "Your data directory is not writable." : "Seu diretório de dados não é gravável.",
    "Setting locale to %s failed." : "Falha ao definir a localidade para %s .",
    "Please install one of these locales on your system and restart your web server." : "Instale um dessas localidades em seu sistema e reinicie seu servidor web.",
    "PHP module %s not installed." : "Módulo PHP %s não instalado.",
    "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está configurado para \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar a configuração no php.ini fará com que o Nextcloud execute novamente",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado para <code>%s</code> em vez do valor esperado <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para corrigir este conjunto de problemas <code>mbstring.func_overload</code> para <code>0</code> no seu php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP aparentemente está configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
    "The required %s config variable is not configured in the config.php file." : "A variável %s de configuração necessária não está configurada no arquivo config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
    "Your data directory is readable by other people." : "Seu diretório de dados pode ser lido por outras pessoas.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Altere as permissões para 0770 para que o diretório não possa ser listado por outras pessoas.",
    "Your data directory must be an absolute path." : "Seu diretório de dados deve ser um caminho absoluto.",
    "Check the value of \"datadirectory\" in your configuration." : "Verifique o valor de \"datadirectory\" em sua configuração.",
    "Your data directory is invalid." : "Seu diretório de dados é inválido.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Certifique-se de que há um arquivo chamado \"%1$s\" na raiz do diretório de dados. Ele deve ter o conteúdo: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
    "Authentication failed, wrong token or provider ID given" : "Falha na autenticação, token ou ID do provedor errados",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parâmetros ausentes para concluir a solicitação: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "A ID \"%1$s\" já é usada pelo provedor de nuvem federada \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Provedor da Federação de Nuvem com ID: \"%s\" não existe.",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
    "Transcribe audio" : "Transcrever áudio",
    "Transcribe the things said in an audio" : "Transcreva as coisas ditas em um áudio",
    "Audio input" : "Entrada de áudio",
    "The audio to transcribe" : "O áudio a ser transcrito",
    "Transcription" : "Transcrição",
    "The transcribed text" : "O texto transcrito",
    "Context write" : "Gravação de contexto",
    "Writes text in a given style based on the provided source material." : "Escreve texto em um determinado estilo com base no material de origem fornecido.",
    "Writing style" : "Estilo de escrita",
    "Demonstrate a writing style that you would like to immitate" : "Demonstre um estilo de escrita que você gostaria de imitar",
    "Source material" : "Material de origem",
    "The content that would like to be rewritten in the new writing style" : "O conteúdo que gostaria de ser reescrito no novo estilo de escrita",
    "Generated text" : "Texto gerado",
    "The generated text with content from the source material in the given style" : "O texto gerado com conteúdo do material de origem no estilo determinado",
    "Emoji generator" : "Gerador de emojis",
    "Takes text and generates a representative emoji for it." : "Pega texto e gera um emoji representativo para ele.",
    "The text to generate an emoji for" : "O texto para gerar um emoji para",
    "Generated emoji" : "Emoji gerado",
    "The generated emoji based on the input text" : "O emoji gerado com base no texto de entrada",
    "Generate image" : "Gerar imagem",
    "Generate an image from a text prompt" : "Gere uma imagem a partir de um prompt de texto",
    "Prompt" : "Pronto",
    "Describe the image you want to generate" : "Descreva a imagem que você deseja gerar",
    "Number of images" : "Número de imagens",
    "How many images to generate" : "Quantas imagens gerar",
    "Output images" : "Imagens de saída",
    "The generated images" : "As imagens geradas",
    "Free text to text prompt" : "Texto livre para prompt de texto",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Usa um modelo de linguagem para gerar uma resposta a partir de um prompt.",
    "Describe a task that you want the assistant to do or ask a question" : "Descreva uma tarefa que você deseja que o assistente execute ou faça uma pergunta",
    "Generated reply" : "Resposta gerada",
    "The generated text from the assistant" : "O texto gerado do assistente",
    "Chat" : "Conversa",
    "Chat with the assistant" : "Converse com o assistente",
    "System prompt" : "Prompt do sistema",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Defina regras e suposições que o assistente deve seguir durante a conversa.",
    "Chat message" : "Mensagem de bate-papo",
    "Chat history" : "Histórico de bate-papo",
    "The history of chat messages before the current message, starting with a message by the user" : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário",
    "Response message" : "Mensagem de resposta",
    "The generated response as part of the conversation" : "A resposta gerada como parte da conversa",
    "Formalize text" : "Formalizar texto",
    "Takes a text and makes it sound more formal" : "Pega um texto e faz com que ele soe mais formal",
    "Write a text that you want the assistant to formalize" : "Escreva um texto que você deseja que o assistente formalize",
    "Formalized text" : "Texto formalizado",
    "The formalized text" : "O texto formalizado",
    "Generate a headline" : "Gere um título",
    "Generates a possible headline for a text." : "Gera um título possível para um texto.",
    "Original text" : "Texto original",
    "The original text to generate a headline for" : "O texto original para gerar um título para",
    "The generated headline" : "O título gerado",
    "Reformulate text" : "Reformular texto",
    "Takes a text and reformulates it" : "Pega um texto e o reformula",
    "Write a text that you want the assistant to reformulate" : "Escrever um texto que você deseja que o assistente reformule",
    "Reformulated text" : "Texto reformulado",
    "The reformulated text, written by the assistant" : "O texto reformulado, escrito pela assistente",
    "Simplify text" : "Simplificar texto",
    "Takes a text and simplifies it" : "Pegar um texto e simplificar ",
    "Write a text that you want the assistant to simplify" : "Escreva um texto que você deseja que o assistente simplifique",
    "Simplified text" : "Texto simplificado",
    "The simplified text" : "O texto simplificado",
    "Summarize" : "Resumir",
    "Summarizes a text" : "Resumir um texto",
    "The original text to summarize" : "O texto original para resumir",
    "Summary" : "Resumo",
    "The generated summary" : "O resumo gerado",
    "Extract topics" : "Extrair tópicos",
    "Extracts topics from a text and outputs them separated by commas" : "Extrai tópicos de um texto e os exibe separados por vírgulas",
    "The original text to extract topics from" : "O texto original para extrair tópicos de",
    "Topics" : "Tópicos",
    "The list of extracted topics" : "A lista de tópicos extraídos",
    "Translate" : "Traduzir",
    "Translate text from one language to another" : "Traduzir o texto de um idioma para outro",
    "Origin text" : "Texto original",
    "The text to translate" : "O texto a ser traduzido",
    "Origin language" : "Idioma original",
    "The language of the origin text" : "O idioma do texto original",
    "Target language" : "Target language",
    "The desired language to translate the origin text in" : "O idioma definido para traduzir o texto original",
    "Result" : "Resultado",
    "The translated text" : "O texto traduzido",
    "Free prompt" : "Solicitação gratuita",
    "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de idioma.",
    "Generate headline" : "Gerar título",
    "Summarizes text by reducing its length without losing key information." : "Resume o texto reduzindo seu comprimento sem perder informações importantes.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrai tópicos de um texto e os gera separados por vírgulas.",
    "Education Edition" : "Edição Educativa",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
    "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
    "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
    "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caracter inválido",
    "File name is too long" : "O nome do arquivo é muito longo",
    "Help" : "Ajuda",
    "Users" : "Usuários",
    "Unknown user" : "Usuário desconhecido",
    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
    "Set an admin username." : "Defina um nome do usuário administrador.",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
    "The username is already being used" : "Este nome de usuário já está em uso",
    "Could not create user" : "Não foi possível criar o usuário",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
    "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
    "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
    "User disabled" : "Usuário desativado",
    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegure-se que exista um arquivo chamado \".ocdata\" na raiz do diretório \"data\"."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
